==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/medias/lang/medias_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/medias?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'Geen geluidsband',
	'aucun_document' => 'Geen document',
	'aucun_file' => 'Geen document',
	'aucun_image' => 'Geen beeld',
	'aucun_video' => 'Geen video',
	'aucune_utilisation' => 'Dit document is nergens gebruikt',
	'aucune_vignette' => 'Geen verkleining',

	// B
	'bouton_ajouter_document' => 'Een document toevoegen',
	'bouton_ajouter_image' => 'Een beeld toevoegen',
	'bouton_ajouter_image_document' => 'Een beeld of een document toevoegen',
	'bouton_attacher_document' => 'Verbinden',
	'bouton_copier_local' => 'Copieren in het site',
	'bouton_download_depuis' => 'vanuit :',
	'bouton_download_local' => 'mijn computer',
	'bouton_download_par_ftp' => 'de server',
	'bouton_download_par_mediatheque' => 'de mediatheek',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Losbinden',
	'bouton_enlever_supprimer_document' => 'Afschaffen',
	'bouton_enlever_supprimer_document_confirmation' => 'Ben je zeker het document willen afschaffen  ?',
	'bouton_modifier_document' => 'Wijzigen',
	'bouton_parcourir' => 'Doorlopen...',
	'bouton_refresh_document' => 'Document opfrissen',
	'bouton_remplacer_document' => 'Dit document vervangen',
	'bouton_remplacer_image' => 'Deze beeld vervangen',
	'bouton_remplacer_image_document' => 'Een beeld of een document vervangen',
	'bouton_supprimer' => 'Afschaffen',
	'bouton_supprimer_tous_orphelins' => 'Alle weesbestanden uitwissen',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Ben je zeker om @nb@ weesbestanden  te willen uitwissen ?',
	'bouton_upload' => 'Uploaden',

	// D
	'des_audios' => '@nb@ geluidsbanden',
	'des_documents' => '@nb@ documenten',
	'des_files' => '@nb@ documenten',
	'des_images' => '@nb@ beelden',
	'des_utilisations' => '@nb@ gebruiken',
	'des_videos' => '@nb@ videosequenties',
	'descriptif' => 'Beschrijving',
	'document_attache_succes' => 'Het document werd bijgevoegd',
	'document_copie_locale_succes' => 'Het bestand werd in de site gekopieerd',
	'document_installe_succes' => 'Het bestand werd opgeslagen',
	'document_vu' => 'In de tekst geplaatst',
	'documents' => 'Mediatheek',
	'documents_brises' => 'Gebroken',
	'documents_distants' => 'Afstandelijke',
	'documents_locaux' => 'Lokaal',
	'documents_non_publies' => 'Niet gepubliceerd',
	'documents_orphelins' => 'Ongebruikte',
	'documents_publies' => 'Gepubliceerde',
	'documents_tous' => 'Alles',
	'double_clic_inserer_doc' => 'Dubbelklik om deze snelkoppeling in de tekst te lassen.',

	// E
	'entree_dimensions' => 'Afmetingen:',
	'entree_titre_document' => 'Documenttitel:',
	'entree_titre_image' => 'Afbeeldingstitel:',
	'erreur_aucun_document' => 'Deze document bestaat niet in de mediatheek ',
	'erreur_aucun_fichier' => 'Geen bestand wordt gevonden',
	'erreur_chemin_distant' => 'Afstandelijk bestand @nom@ werd niet gevonden',
	'erreur_chemin_ftp' => 'Het gekozen bestand werd niet op de server gevonden',
	'erreur_copie_fichier' => 'Onmogelijk het bestand @nom@ te kopiëren ',
	'erreur_dossier_tmp_manquant' => 'Er mist een voorlopige dossier om de bestanden te uploaden',
	'erreur_ecriture_fichier' => 'Fout tijdens het schrijven van het bestand op de server',
	'erreur_format_fichier_image' => 'Het @nom@ formaat is ongeldig voor een beeld',
	'erreur_indiquez_un_fichier' => 'Wijs een bestand aan !',
	'erreur_insertion_document_base' => 'Onmogelijk het document @fichier@ in de databank op te slaan',
	'erreur_suppression_vignette' => 'Fout tijdens het uitwissen van de verkleining',
	'erreur_upload_type_interdit' => 'Het uploaden van bestanden uit de type van  @nom@ is niet toegelaten',
	'erreur_upload_vignette' => 'Fout tijdens het laden van de verkleining @nom@',
	'erreurs' => '@nb@ fouten',
	'erreurs_voir' => 'De @nb@ fouten kijken',

	// F
	'fichier_distant' => 'Afstandelijk bestand',
	'fichier_manquant' => 'Missende bestand',
	'fichier_modifie' => 'Het bestand wordt veranderd. Klik op opslaan.',
	'format_date_incorrect' => 'Datum of uur is ongeldig',

	// I
	'icone_creer_document' => 'Een document bijvoegen',
	'id' => 'ID',
	'image_tourner_180' => '180° draaien',
	'image_tourner_droite' => '90° naar rechts draaien',
	'image_tourner_gauche' => '90° naar links draaien',
	'info_doc_max_poids' => 'De documenten moeten verplicht minder dan @maxi@ wegen (dit bestand is @actuel@ zwaar).',
	'info_document' => 'Document',
	'info_document_indisponible' => 'Dit document is niet beschikbaar',
	'info_documents' => 'documenten',
	'info_gauche_numero_document' => 'DOCUMENT NUMMER',
	'info_hauteur' => 'Hoogte',
	'info_heure' => 'Uur',
	'info_illustrations' => 'Illustraties',
	'info_image_max_poids' => 'De beelden moeten verplicht minder dan @maxi@ wegen (huidige bestand is @actuel@).',
	'info_inclusion_directe' => 'Directe insluiting:',
	'info_inclusion_vignette' => 'Insluiten van de miniatuurafbeelding:',
	'info_installer_tous_documents' => 'Alle documenten installeren',
	'info_largeur' => 'Breedte',
	'info_logo_max_taille' => 'Logo’s mogen maximaal @maxi@ zijn (dit bestand is @actuel@).',
	'info_mode' => 'Modus',
	'info_modifier_document' => 'Document veranderen',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Naar een document op internet verwijzen :',
	'info_sans_vignette' => 'Zonder verkleining',
	'info_statut_document' => 'Deze document is :',
	'info_taille' => 'Gewicht',
	'info_telecharger' => 'Opladen vanf je computer:',
	'infos' => 'Technische infos',
	'item_autoriser_selectionner_date_en_ligne' => 'Het mogelijk maken om de datum van elk document te wijzigen',
	'item_non_autoriser_selectionner_date_en_ligne' => 'De datum van de documenten is die van hun toevoegsel op de plaats',

	// L
	'label_activer_document_objets' => 'Documenten activeren voor volgende inhouden :',
	'label_apercu' => 'Overzicht',
	'label_caracteristiques' => 'Kenmerken',
	'label_credits' => 'Krediet',
	'label_fichier' => 'Bestand',
	'label_fichier_vignette' => 'Verkleining',
	'label_paginer_par' => 'Pagineren door :',
	'label_parents' => 'Deze document is verbonden aan',
	'label_refdoc_joindre' => 'Document nummer',
	'lien_tout_enlever' => 'Alles uittrekken',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Geluidsbanden',
	'media_file' => 'Andere',
	'media_image' => 'Beelden',
	'media_video' => 'Videosequenties',
	'miniature_automatique_active' => 'SPIP zal automatisch een verkleining van het beeld aanmaken',

	// N
	'nb_documents_attache_succes' => '@nb@ documenten werden bijgevoegd',
	'nb_documents_installe_succes' => '@nb@ bestanden opgeslagen met succes ',

	// O
	'objet_document' => 'Document',
	'objet_documents' => 'Documenten',

	// P
	'par_date' => 'Datum',
	'par_hauteur' => 'Hoogte',
	'par_id' => 'ID',
	'par_largeur' => 'Breedte',
	'par_taille' => 'Gewicht',
	'par_titre' => 'Title',

	// T
	'texte_documents_joints' => 'Je kan het toevoegen van documenten (teksten, afbeeldingen, multimedia, ...) bij artikels, rubrieken en andere toelaten. De bijgevoegde bestanden  kunnen vervolgens gekoppeld worden in het 
tekst of afzonderlijk getoond worden.',
	'texte_documents_joints_2' => 'Deze instelling verhindert de directe opname van beelden in artikels niet noch het inzetten van documenten rechtsreeks in de teksten van van andere inhouden.',
	'titre_documents_joints' => 'Bijlagen',
	'titre_page_documents_edit' => 'Het document veranderen: @titre@',
	'tous_les_medias' => 'Alle medias',
	'tout_dossier_upload' => 'Alles in de map @upload@',
	'tout_voir' => 'Alles zien',

	// U
	'un_audio' => '1 geluidsband',
	'un_document' => '1 document',
	'un_file' => '1 document',
	'un_image' => '1 beeld',
	'un_video' => '1 videosequentie',
	'une_utilisation' => '1 gebruik',
	'upload_fichier_zip' => 'ZIP bestand',
	'upload_fichier_zip_texte' => 'Het bestand dat je wil installeren is een ZIP bestand.',
	'upload_fichier_zip_texte2' => 'Dit bestand kan zijn :',
	'upload_info_mode_document' => 'In de portfolio neerzetten',
	'upload_info_mode_image' => 'Uit de portfolio ontnemen ',
	'upload_limit' => 'Dit bestand is te groot voor de server ; de maximale bestandsgrootte voor <i>upload</i> is @max@.',
	'upload_zip_conserver' => 'Het archief behouden na het unzippen',
	'upload_zip_decompacter' => 'uitgepakt en elk bestand geïnstalleerd op de site. De bestanden die op de site komen, zijn :',
	'upload_zip_mode_document' => 'Alle beelden in de portfolio neerleggen',
	'upload_zip_telquel' => 'geïnstalleerd als gezipt (gecomprimeerd) bestand ;',
	'upload_zip_titrer' => 'Volgens de naam bestanden betitelen',

	// V
	'verifier_documents_brises' => 'Missende bestanden checken',
	'verifier_documents_inutilises' => 'Links van de documenten checken',
	'vignette_supprimee' => 'Verkleining wordt uitgewist'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/medias/lang/medias_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/medias?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'Geen geluidsband',
	'aucun_document' => 'Geen document',
	'aucun_file' => 'Geen document',
	'aucun_image' => 'Geen beeld',
	'aucun_video' => 'Geen video',
	'aucune_utilisation' => 'Dit document is nergens gebruikt',
	'aucune_vignette' => 'Geen verkleining',

	// B
	'bouton_ajouter_document' => 'Een document toevoegen',
	'bouton_ajouter_image' => 'Een beeld toevoegen',
	'bouton_ajouter_image_document' => 'Een beeld of een document toevoegen',
	'bouton_attacher_document' => 'Verbinden',
	'bouton_copier_local' => 'Copieren in het site',
	'bouton_download_depuis' => 'vanuit :',
	'bouton_download_local' => 'mijn computer',
	'bouton_download_par_ftp' => 'de server',
	'bouton_download_par_mediatheque' => 'de mediatheek',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Losbinden',
	'bouton_enlever_supprimer_document' => 'Afschaffen',
	'bouton_enlever_supprimer_document_confirmation' => 'Ben je zeker het document willen afschaffen  ?',
	'bouton_modifier_document' => 'Wijzigen',
	'bouton_parcourir' => 'Doorlopen...',
	'bouton_refresh_document' => 'Document opfrissen',
	'bouton_remplacer_document' => 'Dit document vervangen',
	'bouton_remplacer_image' => 'Deze beeld vervangen',
	'bouton_remplacer_image_document' => 'Een beeld of een document vervangen',
	'bouton_supprimer' => 'Afschaffen',
	'bouton_supprimer_tous_orphelins' => 'Alle weesbestanden uitwissen',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Ben je zeker om @nb@ weesbestanden  te willen uitwissen ?',
	'bouton_upload' => 'Uploaden',

	// D
	'des_audios' => '@nb@ geluidsbanden',
	'des_documents' => '@nb@ documenten',
	'des_files' => '@nb@ documenten',
	'des_images' => '@nb@ beelden',
	'des_utilisations' => '@nb@ gebruiken',
	'des_videos' => '@nb@ videosequenties',
	'descriptif' => 'Beschrijving',
	'document_attache_succes' => 'Het document werd bijgevoegd',
	'document_copie_locale_succes' => 'Het bestand werd in de site gekopieerd',
	'document_installe_succes' => 'Het bestand werd opgeslagen',
	'document_vu' => 'In de tekst geplaatst',
	'documents' => 'Mediatheek',
	'documents_brises' => 'Gebroken',
	'documents_distants' => 'Afstandelijke',
	'documents_locaux' => 'Lokaal',
	'documents_non_publies' => 'Niet gepubliceerd',
	'documents_orphelins' => 'Ongebruikte',
	'documents_publies' => 'Gepubliceerde',
	'documents_tous' => 'Alles',
	'double_clic_inserer_doc' => 'Dubbelklik om deze snelkoppeling in de tekst te lassen.',

	// E
	'entree_dimensions' => 'Afmetingen:',
	'entree_titre_document' => 'Documenttitel:',
	'entree_titre_image' => 'Afbeeldingstitel:',
	'erreur_aucun_document' => 'Deze document bestaat niet in de mediatheek ',
	'erreur_aucun_fichier' => 'Geen bestand wordt gevonden',
	'erreur_chemin_distant' => 'Afstandelijk bestand @nom@ werd niet gevonden',
	'erreur_chemin_ftp' => 'Het gekozen bestand werd niet op de server gevonden',
	'erreur_copie_fichier' => 'Onmogelijk het bestand @nom@ te kopiëren ',
	'erreur_dossier_tmp_manquant' => 'Er mist een voorlopige dossier om de bestanden te uploaden',
	'erreur_ecriture_fichier' => 'Fout tijdens het schrijven van het bestand op de server',
	'erreur_format_fichier_image' => 'Het @nom@ formaat is ongeldig voor een beeld',
	'erreur_indiquez_un_fichier' => 'Wijs een bestand aan !',
	'erreur_insertion_document_base' => 'Onmogelijk het document @fichier@ in de databank op te slaan',
	'erreur_suppression_vignette' => 'Fout tijdens het uitwissen van de verkleining',
	'erreur_upload_type_interdit' => 'Het uploaden van bestanden uit de type van  @nom@ is niet toegelaten',
	'erreur_upload_vignette' => 'Fout tijdens het laden van de verkleining @nom@',
	'erreurs' => '@nb@ fouten',
	'erreurs_voir' => 'De @nb@ fouten kijken',

	// F
	'fichier_distant' => 'Afstandelijk bestand',
	'fichier_manquant' => 'Missende bestand',
	'fichier_modifie' => 'Het bestand wordt veranderd. Klik op opslaan.',
	'format_date_incorrect' => 'Datum of uur is ongeldig',

	// I
	'icone_creer_document' => 'Een document bijvoegen',
	'id' => 'ID',
	'image_tourner_180' => '180° draaien',
	'image_tourner_droite' => '90° naar rechts draaien',
	'image_tourner_gauche' => '90° naar links draaien',
	'info_doc_max_poids' => 'De documenten moeten verplicht minder dan @maxi@ wegen (dit bestand is @actuel@ zwaar).',
	'info_document' => 'Document',
	'info_document_indisponible' => 'Dit document is niet beschikbaar',
	'info_documents' => 'documenten',
	'info_gauche_numero_document' => 'DOCUMENT NUMMER',
	'info_hauteur' => 'Hoogte',
	'info_heure' => 'Uur',
	'info_illustrations' => 'Illustraties',
	'info_image_max_poids' => 'De beelden moeten verplicht minder dan @maxi@ wegen (huidige bestand is @actuel@).',
	'info_image_max_taille' => 'De beelden moeten verplicht minder dan @maxi@ wegen (huidige bestand is @actuel@).',
	'info_inclusion_directe' => 'Directe insluiting:',
	'info_inclusion_vignette' => 'Insluiten van de miniatuurafbeelding:',
	'info_installer_tous_documents' => 'Alle documenten installeren',
	'info_largeur' => 'Breedte',
	'info_logo_max_taille' => 'Logo’s mogen maximaal @maxi@ zijn (dit bestand is @actuel@).',
	'info_mode' => 'Modus',
	'info_modifier_document' => 'Document veranderen',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Naar een document op internet verwijzen :',
	'info_sans_vignette' => 'Zonder verkleining',
	'info_statut_document' => 'Deze document is :',
	'info_taille' => 'Gewicht',
	'info_telecharger' => 'Opladen vanf je computer:',
	'infos' => 'Technische infos',
	'item_autoriser_selectionner_date_en_ligne' => 'Het mogelijk maken om de datum van elk document te wijzigen',
	'item_non_autoriser_selectionner_date_en_ligne' => 'De datum van de documenten is die van hun toevoegsel op de plaats',

	// L
	'label_activer_document_objets' => 'Documenten activeren voor volgende inhouden :',
	'label_apercu' => 'Overzicht',
	'label_caracteristiques' => 'Kenmerken',
	'label_credits' => 'Krediet',
	'label_fichier' => 'Bestand',
	'label_fichier_vignette' => 'Verkleining',
	'label_paginer_par' => 'Pagineren door :',
	'label_parents' => 'Deze document is verbonden aan',
	'label_refdoc_joindre' => 'Document nummer',
	'lien_tout_enlever' => 'Alles uittrekken',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Geluidsbanden',
	'media_file' => 'Andere',
	'media_image' => 'Beelden',
	'media_video' => 'Videosequenties',
	'miniature_automatique_active' => 'SPIP zal automatisch een verkleining van het beeld aanmaken',

	// N
	'nb_documents_attache_succes' => '@nb@ documenten werden bijgevoegd',
	'nb_documents_installe_succes' => '@nb@ bestanden opgeslagen met succes ',

	// O
	'objet_document' => 'Document',
	'objet_documents' => 'Documenten',

	// P
	'par_date' => 'Datum',
	'par_hauteur' => 'Hoogte',
	'par_id' => 'ID',
	'par_largeur' => 'Breedte',
	'par_taille' => 'Gewicht',
	'par_titre' => 'Title',

	// T
	'texte_documents_joints' => 'Je kan het toevoegen van documenten (teksten, afbeeldingen, multimedia, ...) bij artikels, rubrieken en andere toelaten. De bijgevoegde bestanden  kunnen vervolgens gekoppeld worden in het 
tekst of afzonderlijk getoond worden.',
	'texte_documents_joints_2' => 'Deze instelling verhindert de directe opname van beelden in artikels niet noch het inzetten van documenten rechtsreeks in de teksten van van andere inhouden.',
	'titre_documents_joints' => 'Bijlagen',
	'titre_page_documents_edit' => 'Het document veranderen: @titre@',
	'tous_les_medias' => 'Alle medias',
	'tout_dossier_upload' => 'Alles in de map @upload@',
	'tout_voir' => 'Alles zien',

	// U
	'un_audio' => '1 geluidsband',
	'un_document' => '1 document',
	'un_file' => '1 document',
	'un_image' => '1 beeld',
	'un_video' => '1 videosequentie',
	'une_utilisation' => '1 gebruik',
	'upload_fichier_zip' => 'ZIP bestand',
	'upload_fichier_zip_texte' => 'Het bestand dat je wil installeren is een ZIP bestand.',
	'upload_fichier_zip_texte2' => 'Dit bestand kan zijn :',
	'upload_info_mode_document' => 'In de portfolio neerzetten',
	'upload_info_mode_image' => 'Uit de portfolio ontnemen ',
	'upload_limit' => 'Dit bestand is te groot voor de server ; de maximale bestandsgrootte voor <i>upload</i> is @max@.',
	'upload_zip_conserver' => 'Het archief behouden na het unzippen',
	'upload_zip_decompacter' => 'uitgepakt en elk bestand geïnstalleerd op de site. De bestanden die op de site komen, zijn :',
	'upload_zip_mode_document' => 'Alle beelden in de portfolio neerleggen',
	'upload_zip_telquel' => 'geïnstalleerd als gezipt (gecomprimeerd) bestand ;',
	'upload_zip_titrer' => 'Volgens de naam bestanden betitelen',

	// V
	'verifier_documents_brises' => 'Missende bestanden checken',
	'verifier_documents_inutilises' => 'Links van de documenten checken',
	'vignette_supprimee' => 'Verkleining wordt uitgewist'
);

?>
